# ucsc

**DOI:** [10.5281/zenodo.10011489](https://doi.org/10.5281/zenodo.10011489)

## Available Versions
- **Version 3.7.7**
  - [Download](https://zenodo.org/record/10011490/files/ucsc_3.7.7.img)
  - **MD5:** `8a4fc249f50096c9c518abda629f9e23`
  - **DOI:** [10.5281/zenodo.10011490](https://doi.org/10.5281/zenodo.10011490)
  - **Size:** 142.02 MB
  - **Binaries:** 0 available

## Binaries (4 total)

```bedGraphToBigWig bedCoverage bedToBigBed bedIntersect```
